==> haskell-wai-cors-0.2.6-78-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-cors
version: 0.2.6
id: wai-cors-0.2.6-7uVvdXkExW16LBDY3gIlEd
key: wai-cors-0.2.6-7uVvdXkExW16LBDY3gIlEd
license: MIT
copyright: (c) 2015-2017 Lars Kuhtz <lakuhtz@gmail.com>,
           (c) 2014 AlephCloud Systems, Inc.
maintainer: Lars Kuhtz <lakuhtz@gmail.com>
author: Lars Kuhtz <lakuhtz@gmail.com>
homepage: https://github.com/larskuhtz/wai-cors
synopsis: CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.
category: HTTP, Network, Web, Yesod
abi: 21241720a0742b0f0fe2736f302f7629
exposed: True
exposed-modules:
    Network.Wai.Middleware.Cors
import-dirs: /usr/lib/ghc-8.6.4/site-local/wai-cors-0.2.6
library-dirs: /usr/lib/ghc-8.6.4/site-local/wai-cors-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/wai-cors-0.2.6
hs-libraries: HSwai-cors-0.2.6-7uVvdXkExW16LBDY3gIlEd
depends:
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    base-unicode-symbols-0.2.3-DSwrVFFd7W25G8H5XUgcPz
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    http-types-0.12.3-7ETbM18iSLZB08qGmmgPmt mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.2-7UZCsmzPTqFA7VskjtEotY
haddock-interfaces: /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html: /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-cors-0.2.6-80-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wai-cors.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-cors
version: 0.2.6
id: wai-cors-0.2.6-Jm6YNEf0n05ItLX8tTXjA9
key: wai-cors-0.2.6-Jm6YNEf0n05ItLX8tTXjA9
license: MIT
copyright: (c) 2015-2017 Lars Kuhtz <lakuhtz@gmail.com>,
           (c) 2014 AlephCloud Systems, Inc.
maintainer: Lars Kuhtz <lakuhtz@gmail.com>
author: Lars Kuhtz <lakuhtz@gmail.com>
homepage: https://github.com/larskuhtz/wai-cors
synopsis: CORS for WAI
description:
    This package provides an implemenation of
    Cross-Origin resource sharing (CORS) for
    <http://hackage.haskell.org/package/wai Wai>
    that aims to be compliant with <http://www.w3.org/TR/cors>.
category: HTTP, Network, Web, Yesod
abi: ccb55585e04e99153fe99e05edf8e4f3
exposed: True
exposed-modules:
    Network.Wai.Middleware.Cors
import-dirs: /usr/lib/ghc-8.6.4/site-local/wai-cors-0.2.6
library-dirs: /usr/lib/ghc-8.6.4/site-local/wai-cors-0.2.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/wai-cors-0.2.6
hs-libraries: HSwai-cors-0.2.6-Jm6YNEf0n05ItLX8tTXjA9
depends:
    attoparsec-0.13.2.2-6cOh3sci63HJyadcbPhvpT base-4.12.0.0
    base-unicode-symbols-0.2.3-DSwrVFFd7W25G8H5XUgcPz
    bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu
    http-types-0.12.3-IdIFkPvozmRFdXetXaEgxE mtl-2.2.2
    transformers-0.5.6.2 wai-3.2.2-6o6QSnPVpAu2Kn1dd7YFx6
haddock-interfaces: /usr/share/doc/haskell-wai-cors/html/wai-cors.haddock
haddock-html: /usr/share/doc/haskell-wai-cors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
